Extraction
==========

.. _extraction:

Introduction
------------
The extraction module can be used for extracting HTML and article text from a given URL.

Usage
-----

To use the module:

.. code-block:: console

    >>> import coast_core
    >>> coast_core.extraction.function(to_use)

or:

.. code-block:: console

    >>> from coast_core import extraction
    >>> extraction.function(to_use)

Functions
---------
.. automodule:: coast_core.extraction
    :members:
    :undoc-members:
    :show-inheritance:
